/*
 *  swifota.h
 *  swimac
 *
 *  Created by Mark de Jong on 5/27/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWI_FOTA_H__
#define __SWI_FOTA_H__

#import "swimacdatatypes.h"

#ifdef cplusplus
extern "C" {
#endif

// FOTA Notifications
/*
SWI_NOTIFY_DM_DL_Progress		-- Sent during FOTA package download
								-- Provides package download progress (DL bytes/Total Bytes)
							
SWI_NOTIFY_DM_DL_Alert			-- Sent when FOTA package available for Install
								-- Contains estimated download,estimated install times
								-- Contains package name
							
SWI_NOTIFY_DM_DL_InstallStatus	-- Sent when modem begins package installation
								-- Sent if error occurs during installation (before modem goes offline)
*/								

#define MAX_DL_PKG_NAME			232		// Set to a 'Max' value for current CNS limitations
#define MAX_DL_DESCRIPTION		1024	// Set to a 'Max' value that should not be exceeded (ever)

enum SWI_TYPE_DM_DL_PROGRESS_TYPE
{
	DM_DL_PROGRESS_TYPE_NO_PKG		= 0x00,
	DM_DL_PROGRESS_TYPE_FOTA_PKG	= 0x01,
	DM_DL_PROGRESS_TYPE_RESERVED	= 0x02,
};

typedef struct SWI_STRUCT_DM_DL_PROGRESS
{
	SWI_U32 sizeStruct;
	SWI_U8	nDLType;				//Download Type (see SWI_TYPE_DM_DL_PROGRESS_TYPE)
	SWI_U32	nBytesDownloaded;		//Number of bytes that have been downloaded 
	SWI_U32	nTotalBytes;			//Size of Package to download in bytes
} SWI_STRUCT_DM_DL_PROGRESS;

enum SWI_TYPE_DM_DL_VALID_RESP
{
	DM_DL_VALID_RESP_REJECT		= 0x01,
	DM_DL_VALID_RESP_CONFIRM	= 0x02,
	DM_DL_VALID_RESP_DELAY		= 0x04, //may not be valid for some carriers (ie. Sprint for now).
};

enum SWI_TYPE_DM_DL_ALERT_PROMPT
{
	DM_DL_ALERT_PROMPT_DL_AND_INSTALL	= 0x00,
	DM_DL_ALERT_PROMPT_INSTALL_ONLY		= 0x01,
};


typedef struct SWI_STRUCT_DM_DL_ALERT
{
	SWI_U32 sizeStruct;
	SWI_U16 nReserved;
	SWI_U8	nValidResponses;		//+mask+ of valid Alert responses, see SWI_TYPE_DM_DL_VALID_RESP_TYPE
	SWI_U8	nAlertType;				//see SWI_TYPE_DM_DL_ALERT_PROMPT
	SWI_U8	bDescAvail;				//boolean to indicate if Description text is available.  
								//Description text is retrieved using SwiGetDMDLDescription()
	SWI_U16 nEstDLTime;				//Estimated download time in seconds
	SWI_U16 nEstInstTime;			//Estimated install time in seconds
	SWI_U16	nTimeout;				//Indicates when the modem will timeout the response in seconds
	SWI_U16 nPkgNameLen;			//Length of Package name (0 - 233 chars)
	SWI_U8	sName[MAX_DL_PKG_NAME];	//Package name (non-Null terminated)			
} SWI_STRUCT_DM_DL_ALERT;



enum SWI_TYPE_DM_DL_ALERT_RESP		//Valid responses are set in DM-DL Alert notification (see above struct)
{
	DM_DL_ALERT_RESP_REJECT		= 0x00,
	DM_DL_ALERT_RESP_CONFIRM	= 0x01,
	DM_DL_ALERT_RESP_DELAY		= 0x02, 
};


enum SWI_TYPE_DM_DL_ALERT_RESP_STATUS
{
	DM_DL_ALERT_RESP_STATUS_SUCCESS					= 0x00,
	DM_DL_ALERT_RESP_STATUS_FAILED_UNSPECIFIED		= 0x01,
	DM_DL_ALERT_RESP_STATUS_FAILED_INVALID_RESPONSE = 0x02,
};

typedef struct SWI_STRUCT_DM_DL_DESCRIPTION
{
	SWI_U32 sizeStruct;
	SWI_U16	nReserved;
	SWI_U16 nDescLength;						// 0 - MAX_DL_DESCRIPTION
	SWI_U8  sDescription[MAX_DL_DESCRIPTION];	//variable length text (not NULL terminated)
} SWI_STRUCT_DM_DL_DESCRIPTION;

enum SWI_TYPE_DM_DL_INSTALL_STATE
{
	DM_DL_INSTALL_STATE_NULL				= 0x00,
	DM_DL_INSTALL_STATE_INSTALL_STARTING	= 0x01,
	DM_DL_INSTALL_STATE_INSTALL_SUCCESS		= 0x02,		
	DM_DL_INSTALL_STATE_FAIL				= 0xFF, //DM Status code contains Error Number.
};
	
typedef struct SWI_STRUCT_DM_DL_INSTALL_STATUS
{
	SWI_U32 sizeStruct;
	SWI_U16 nEstInstallTime;		//Estimated install time in seconds
	SWI_U8	nInstallState;			//Current state/result of install process (SWI_TYPE_DM_DL_INSTALL_STATE)
	SWI_U16 nDMStatusCode;			//DM status code (use for more detailed failure description)
} SWI_STRUCT_DM_DL_INSTALL_STATUS;

//////////////////////////////////////////////////////////////////////////////////
//
//	Name:		SwiSetDMDLAlertResponse - Set DM Download Alert Response
//
//	Purpose:	This function sets a DM Download Alert Response from a SWI_NOTIFY_DM_DL_Alert.
//				This alert notification is sent from the modem when a DM DL package is ready 
//				for download and/or install.
//
// Parameters:	nResponse[In]			User response to alert (see SWI_TYPE_DM_DL_ALERT_RESP)     	         
//              pStatus[Out]			Status of response from modem- 0:Success
//																	   1:Fail - unspecified
//																	   2:Fail - invalid response
//                            
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error (see status for error code)
//
// Notes:       See SwiStructsCm.h for SWI_TYPE_DM_DL_ALERT_RESP definition
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetDMDLAlertResponse(const SWI_U8 nResponse, SWI_U8* pStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDMDLProgress - Get DM Download progress
//
// Purpose:     This function gets the progress of the DM Download.  This same
//				information is provided in the SWI_NOTIFY_DM_DL_Progress
//				notification when a download is in progress.
//
// Parameters:  psProgress[Out]			Contains progress info. (see SWI_STRUCT_DM_DL_PROGRESS)
//                            
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructsCm.h for SWI_STRUCT_DM_DL_PROGRESS definition
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDMDLProgress(SWI_STRUCT_DM_DL_PROGRESS *psProgress, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDMDLDescription - Get DM Download Description information
//
// Purpose:     This function gets the the DM Download description text if available.
//				When the SWI_NOTIFY_DM_DL_Alert notification is received, the
//				nDescAvail parameter will be set if a description is available. 
//
// Parameters:  psDescription[Out]				Description (see SWI_STRUCT_DM_DL_DESCRIPTION)
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructsCm.h for definition
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDMDLDescription(SWI_STRUCT_DM_DL_DESCRIPTION *psDescription, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDMDLInstallStatus - Get DM Download install status
//
// Purpose:     This function gets the status of the DM Download install.  When the install
//				begins, the modem will send a SWI_NOTIFY_DM_DL_InstallStatus notification and
//				the modem will de-enumerate from the system (Device Removal) and complete the install.
//				Once the install is complete, the modem will re-enumerate on the system (Device 
//				Arrival) and this API should be call (after normal API re-init) to determine the
//				status of the install.
//
// Parameters:  psStatus[In]			Status of install (see SWI_STRUCT_DM_DL_INSTALL_STATUS)
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructsCm.h for definition
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDMDLInstallStatus(SWI_STRUCT_DM_DL_INSTALL_STATUS *psStatus, SWI_U32 timeout);


//**********************************************************************************
//	SwiGetFOTAData
//		This call returns all the FOTA data in one structure
//		the primary use is to check all the "GET" calls for
//		FOTA.  NOTE -- most data will be invalid if FOTA session
//		is not in progress.
//**********************************************************************************
typedef struct allFOTAData
{
	SWI_RCODE								_ret[3];
	SWI_STRUCT_DM_DL_PROGRESS				_progress;
	SWI_STRUCT_DM_DL_DESCRIPTION			_description;
	SWI_STRUCT_DM_DL_INSTALL_STATUS			_installStatus;
} allFOTAData;


SWI_RCODE SwiGetFOTAData(allFOTAData *data);




#ifdef cplusplus
}
#endif

#endif // __SWI_FOTA_H__
