/*
 *  swimacomadm.h
 *  Sierra Wireless Mac SDK
 *
 *  Created by Jerry Pickering on 11/6/07.
 *  Copyright 2007 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIMACOMADM_H__
#define __SWIMACOMADM_H__

#ifdef __cplusplus
extern "C"	{
#endif
 
#import "swimacomadmStructs.h"


// *********************** OMA-DM APIs ****************************************

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetOMADMConfig - Get OMA-DM Configuration
//
// Purpose:     This function gets the current OMA-DM configuration supported by
//              the device
//
// Parameters:  psConfig[OUT]	  Struct containing configuration params
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_GET_CONFIG definition.
//
// Notification: SWI_NOTIFY_OMADM_Config
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetOMADMConfig(SWI_STRUCT_OMADM_GET_CONFIG *psConfig, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMConfig - Set OMA-DM Configuration
//
// Purpose:     This function sets the current OMA-DM configuration in the device
//
// Parameters:  psConfig[IN]	  Struct containing configuration params
//              pStatus[OUT]    contains OMADM error status if rCode is SWI_RCODE_OMADM_ERROR
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_SET_CONFIG definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMConfig(const SWI_STRUCT_OMADM_SET_CONFIG *psConfig, 
                                    SWI_TYPE_OMADM_SET_RESP *pStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiStartOMADMSession - Start a OMA-DM Session
//
// Purpose:     This function requests the device to start a OMA-DM session.
//
// Parameters:  psConfig[IN]	  Struct containing configuration params
//              pStatus[OUT]    contains OMADM error status if rCode is SWI_RCODE_OMADM_ERROR
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_START_SESSION definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiStartOMADMSession(const SWI_STRUCT_OMADM_START_SESSION *psSession, 
                                       SWI_TYPE_OMADM_SET_RESP *pStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiCancelOMADMSession - Cancel a OMA-DM Session
//
// Purpose:     This function requests the device to cancel a OMA-DM session.
//
// Parameters:  pStatus[OUT]            Contains OMADM cancel status information
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_CANCEL definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiCancelOMADMSession(SWI_STRUCT_OMADM_CANCEL_RESP *pStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetOMADMSessionState - Get OMA-DM Session State
//
// Purpose:     This function gets the current OMA-DM session state information
//
// Parameters:  psState[OUT]	          Contains OMA-DM session state information
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_SESSION_STATE definition.
//
// Notification: SWI_NOTIFY_OMADM_State
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetOMADMSessionState(SWI_STRUCT_OMADM_SESSION_STATE *psState, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetOMADMNIAlert - Get OMA-DM Network Initiated Alert
//
// Purpose:     This function gets OMA-DM Network Initiated Alert information stored
//              in the device
//
// Parameters:  psAlert[OUT]	          Contains OMA-DM NI Alert information
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_NI_ALERT definition.
//
// Notification: SWI_NOTIFY_OMADM_NI_Alert
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetOMADMNIAlert(SWI_STRUCT_OMADM_NI_ALERT *psAlert, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMNIAlertResponse - Set OMA-DM Network Initiated Alert response
//
// Purpose:     This function is a response to the NI Alert
//
// Parameters:  nResponse[IN]	          0 = Deny; 1 = Allow
//              psStatus[OUT]           Contains OMADM response status 
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_NI_ALERT_RESP definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMNIAlertResponse(const SWI_U16 nResponse, 
                                             SWI_STRUCT_OMADM_NI_ALERT_RESP *psStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMUIAlertConfirm - Set OMA-DM UI Alert confirm
//
// Purpose:     This function sends a confirmation response to the UI Alert Confirmation message.
//
// Parameters:  psConfirm[IN]	          Structure contains confirmation to alert
//              pConfResp[OUT]          Contains response to confirmation (0 = Success, 1 = Fail)
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_UI_ALERT_CONFIRM_RESP definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMUIAlertConfirm(const SWI_STRUCT_OMADM_UI_ALERT_CONFIRM_RESP *psConfirm,
                                            SWI_U16 *pConfResp, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMUIAlertInput - Set OMA-DM UI Alert input
//
// Purpose:     This function sends an input response to the UI Alert Input message.
//
// Parameters:  psInput[IN]  	          Structure contains input response to the alert
//              pInputResp[OUT]         Contains response to input response (0 = Success, 1 = Fail)
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_UI_ALERT_INPUT_RESP definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMUIAlertInput(const SWI_STRUCT_OMADM_UI_ALERT_INPUT_RESP *psInput,
                                          SWI_U16 *pInputResp, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMUIAlertChoice - Set OMA-DM UI Alert choice
//
// Purpose:     This function sends a choice response to the UI Alert choice message.
//
// Parameters:  psChoice[IN]  	        Structure contains choice response to the alert
//              pConfResp[OUT]          Contains response to input response: 0 = Success 
//                                                                           1 = Fail - unspecified reason, 
//                                                                           2 = Fail - choice type + response mismatch
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_UI_ALERT_CHOICE_RESP definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMUIAlertChoice(const SWI_STRUCT_OMADM_UI_ALERT_CHOICE_RESP *psChoice,
                                           SWI_U16 *pConfResp, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMBootAlgorithm - Set OMA-DM Boot Algorithm
//
// Purpose:     This function commands the modem to update any per unit DM session
//              configuration values in the device's management tree 
//
// Parameters:  pStatus[Out]  	        Result of operation
//              
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMBootAlgorithm(SWI_U16 *pStatus, SWI_U32 timeout);
           
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetOMADMNodeValue - Get OMA-DM Tree Node Value
//
// Purpose:     This function gets a DM tree node value.
//
// Parameters:  psItem[In]     	        Node value to retrieve
//              psValue[Out]             Node value data
//              
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_NODE_VALUE_REQUEST/RESPONSE definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetOMADMNodeValue(const SWI_STRUCT_OMADM_NODE_VALUE_REQUEST *psItem,
                                       SWI_STRUCT_OMADM_NODE_VALUE_RESPONSE *psValue, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetOMADMNodeValue - Set OMA-DM Tree Node Value
//
// Purpose:     This function sets a DM tree node value.
//
// Parameters:  psValue[In]     	        Node value item and data 
//              pStatus[Out]              Status of operation (see SWI_TYPE_OMADM_NODE_VALUE_RESP_STATUS)
//              
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//              SWI_RCODE_OMADM_ERROR   The OMADM service returned an error (see status for error code)
//
// Notes:       See SwiStructs.h for SWI_STRUCT_OMADM_NODE_VALUE/RESPONSE definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetOMADMNodeValue(const SWI_STRUCT_OMADM_NODE_VALUE *psValue, SWI_U8 *pStatus, SWI_U32 timeout);
                     


//**********************************************************************************
//	SwiGetOMADMData
//		This call returns all the OMADM data in one structure
//		the primary use is to check all the "GET" calls for
//		OMADM
//**********************************************************************************
typedef struct allOMADMData
{
	SWI_RCODE								_ret[4];
	SWI_STRUCT_OMADM_GET_CONFIG				_getConfig;
	SWI_STRUCT_OMADM_SESSION_STATE			_sessionState;
	SWI_STRUCT_OMADM_NI_ALERT				_niAlert;
	SWI_STRUCT_OMADM_NODE_VALUE_REQUEST		_nodeValueRequest;
	SWI_STRUCT_OMADM_NODE_VALUE_RESPONSE	_nodeValueResponse;
} allOMADMData;


SWI_RCODE SwiGetOMADMData(allOMADMData *data);

#ifdef __cplusplus
}
#endif

#endif // __SWIMACOMADM_H__

