/*
 *  OMADMStructs.h
 *  ActivationSample
 *
 *  Created by Jerry Pickering on 11/6/07.
 *  Copyright 2007 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifdef __cplusplus
extern "C"	{
#endif

// OMA-DM Types and Structures
typedef enum 
{
  OMADM_DEVICE_CAPABILITY_NONE                = 0x00,
  OMADM_DEVICE_CAPABILITY_SWI                 = 0x01,
  OMADM_DEVICE_CAPABILITY_REDBEND             = 0x02,
}SWI_TYPE_OMADM_DEVICE_CAPABILITY;

typedef enum 
{
                                              
  OMADM_FEATURE_CIDC                          = 0x00000001,
  OMADM_FEATURE_NIDC                          = 0x00000002,
  OMADM_FEATURE_CIPRL                         = 0x00000004,
  OMADM_FEATURE_NIPRL                         = 0x00000008,
  OMADM_FEATURE_CIFUMO                        = 0x00000010,
  OMADM_FEATURE_NIFUMO                        = 0x00000020,
  OMADM_FEATURE_HFA                           = 0x00000040,
}SWI_TYPE_OMADM_FEATURE_CAPABILITY;                                            

typedef struct SWI_STRUCT_OMADM_GET_CONFIG
{
  SWI_U32											sizeStruct;
  SWI_TYPE_OMADM_DEVICE_CAPABILITY				nOMADMCapability;
  SWI_U8                                          nMaxAcctSupport;        //1 - 8
  SWI_U8                                          nNumAccts;              //0 - 8
  SWI_U8                                          bAcctChanged;           //used to notify if acount support/number changes
  SWI_U32                                         dwFeatureCapabilityMask;//what features are supported (SWI_TYPE_OMADM_FEATURE_CAPABILITY)
  SWI_U32                                         dwFeatureEnableMask;    //feature enable state (SWI_TYPE_OMADM_FEATURE_CAPABILITY)
  SWI_U8											 bHFAAttempted;          //TRUE if HFA has been attempted (only if HFA supported)
}SWI_STRUCT_OMADM_GET_CONFIG;

typedef enum SWI_TYPE_OMADM_STATUS_RESP
{
	OMADM_STATUS_RESP_SUCCESS                   = 0x00,
	OMADM_STATUS_RESP_FAIL                      = 0x01,
	OMADM_STATUS_RESP_UNSUPPORTED               = 0x02,
	OMADM_STATUS_RESP_BAD_PARAM                 = 0x03,
	OMADM_STATUS_RESP_INVALID_OPTION            = 0x04,
	OMADM_STATUS_RESP_SECURITY_ACCESS_DENIED    = 0x05,
	OMADM_STATUS_RESP_INVALID_DEVICE_STATE      = 0x06,
	OMADM_STATUS_RESP_INVALID_SESSION_STATE     = 0x07,
	OMADM_STATUS_RESP_UNSUPPORTED_NODE          = 0x08,
	OMADM_STATUS_RESP_NODE_ALREADY_EXISTS       = 0x09,
	OMADM_STATUS_RESP_MAX_URI_EXCEEDED          = 0x0A,
} SWI_TYPE_OMADM_STATUS_RESP;

typedef enum  
{
  OMADM_SET_RESP_SUCCESS                      = 0x00,
  OMADM_SET_RESP_FAIL                         = 0x01,
  OMADM_SET_RESP_UNSUPPORTED                  = 0x02,
  OMADM_SET_RESP_BAD_PARAM                    = 0x03,
  OMADM_SET_RESP_INVALID_OPTION               = 0x04,
  OMADM_SET_RESP_SECURITY_ACCESS_DENIED    = 0x05,
  OMADM_SET_RESP_INVALID_DEVICE_STATE      = 0x06,
  OMADM_SET_RESP_INVALID_SESSION_STATE     = 0x07,
  OMADM_SET_RESP_UNSUPPORTED_NODE          = 0x08,
  OMADM_SET_RESP_NODE_ALREADY_EXISTS       = 0x09,
  OMADM_SET_RESP_MAX_URI_EXCEEDED          = 0x0A,
} SWI_TYPE_OMADM_SET_RESP;

typedef struct SWI_STRUCT_OMADM_SET_CONFIG
{
  SWI_U32                                         sizeStruct;
  SWI_U32                                         dwFeatureCapabilityMask; //what features are supported (SWI_TYPE_OMADM_FEATURE_CAPABILITY)
  SWI_U32                                         dwFeatureEnableMask;     //feature enable state (SWI_TYPE_OMADM_FEATURE_CAPABILITY)
  SWI_U8                                          bResetHFA;               //Set TRUE to reset HFA flag (reattempt HFA upon next power cycle)
}SWI_STRUCT_OMADM_SET_CONFIG;


typedef enum 
{
	OMADM_SESSION_TYPE_UNKNOWN				= 0x00,
	OMADM_SESSION_TYPE_DEVICE_CONFIG		= 0x01,
	OMADM_SESSION_TYPE_CDMA_PRL_UPDATE		= 0x02,
	OMADM_SESSION_TYPE_FUMO_INFO_EXCHANGE	= 0x03, //FUMO Information Exchanged
	OMADM_SESSION_TYPE_HFA					= 0x04,
	OMADM_SESSION_TYPE_DD_DOWNLOAD			= 0x05, //Download Descriptor Download
	OMADM_SESSION_TYPE_PKG_DOWNLOAD		= 0x06, //FUMO Package Download
	OMADM_SESSION_TYPE_STATUS_REPORT		= 0x07, //Status update to OMADM Server
}SWI_TYPE_OMADM_SESSION_TYPE;

typedef enum SWI_TYPE_OMADM_USER_CI_SESSION_TYPE
{
	OMADM_USER_CI_SESSION_TYPE_UNKNOWN				= 0x00,	// Placeholder
	OMADM_USER_CI_SESSION_TYPE_DEVICE_CONFIG		= 0x01,	// Device Configuration
	OMADM_USER_CI_SESSION_TYPE_CDMA_PRL_UPDATE	= 0x02,	// CDMA PRL Update
	OMADM_USER_CI_SESSION_TYPE_FUMO				= 0x03,	// FUMO
} SWI_TYPE_OMADM_USER_CI_SESSION_TYPE;
	
typedef struct  SWI_STRUCT_OMADM_START_SESSION
{
	SWI_U32									sizeStruct;
	SWI_TYPE_OMADM_USER_CI_SESSION_TYPE	nType;				// Type of session to start       
	SWI_U8										nAcctNameLen;		// Account name length (0 if default)
	SWI_U8										psAcctName[1];	// Variable length Account name
}SWI_STRUCT_OMADM_START_SESSION;


typedef enum 
{
	OMADM_CANCEL_SUCCESS			= 0x00,
	OMADM_CANCEL_NO_SESSION		= 0x01,
}SWI_TYPE_OMADM_CANCEL_STATUS;

typedef struct SWI_STRUCT_OMADM_CANCEL_RESP
{
	SWI_U32							sizeStruct;
	SWI_TYPE_OMADM_CANCEL_STATUS	nStatus;
	SWI_U8								bQueuedForReattempt;
}SWI_STRUCT_OMADM_CANCEL_RESP;


typedef enum 
{
	OMADM_SESSION_STATE_IDLE			= 0x00,
	OMADM_SESSION_STATE_ACTIVE			= 0x01,
	OMADM_SESSION_STATE_HFA_PENDING	= 0x02,
}SWI_TYPE_OMADM_SESSION_STATE;

typedef enum 
{
	OMADM_SESSION_INITIATOR_UNKNOWN			= 0x00,
	OMADM_SESSION_INITIATOR_USER_CLIENT		= 0x01,
	OMADM_SESSION_INITIATOR_DEVICE_CLIENT		= 0x02,
	OMADM_SESSION_INITIATOR_NETWORK			= 0x03,
}SWI_TYPE_OMADM_SESSION_INITIATOR;

typedef enum 
{
	OMADM_SESSION_UI_MODE_UNKNOWN		= 0x00,
	OMADM_SESSION_UI_MODE_HIDDEN		= 0x01,
	OMADM_SESSION_UI_MODE_UNHIDDEN		= 0x02,
}SWI_TYPE_OMADM_SESSION_UI_MODE;

typedef enum 
{
  OMADM_SESSION_RESULT_SUCCESS                = 0x0000,
  OMADM_SESSION_RESULT_FAIL                   = 0x0001,
  OMADM_SESSION_RESULT_NO_COMMANDS_RECEIVED   = 0x0002,
  OMADM_SESSION_RESULT_ABORT_CLIENT_USER      = 0x0100,
  OMADM_SESSION_RESULT_ABORT_CLIENT_DEVICE    = 0x0101,
  OMADM_SESSION_RESULT_ABORT_SERVER           = 0x0102,
  OMADM_SESSION_RESULT_MEMORY_ERROR           = 0x0200,
  OMADM_SESSION_RESULT_HEAP_TOO_SMALL         = 0x0201,
  OMADM_SESSION_RESULT_BUFFER_TOO_SMALL       = 0x0202,
  OMADM_SESSION_RESULT_ROUTINE_NOT_ALLOWED    = 0x0300,
  OMADM_SESSION_RESULT_ROUTINE_WHEN_SUSPEND   = 0x0301,
  OMADM_SESSION_RESULT_BAD_INPUT_PARAM        = 0x0302,
  OMADM_SESSION_RESULT_INVALID_PROTOCOL       = 0x0400,
  OMADM_SESSION_RESULT_AUTH_FAILURE           = 0x0401,
  OMADM_SESSION_RESULT_MISSING_START_MSG      = 0x0402,
  OMADM_SESSION_RESULT_MISSING_END_MSG        = 0x0403,
  OMADM_SESSION_RESULT_FEATURE_NOT_AVAIL      = 0x0404,
  OMADM_SESSION_RESULT_UIA_PARSE_ERROR        = 0x0405,
  OMADM_SESSION_RESULT_DATA_TOO_BIG_TO_RTN    = 0x0406,
  OMADM_SESSION_RESULT_UNSUPPORTED_PROTOCOL   = 0x0500,
  OMADM_SESSION_RESULT_MIME_TYPE_MISMATCH     = 0x0501,
  OMADM_SESSION_RESULT_NTWK_FAIL_TO_OPEN      = 0x0502,
  OMADM_SESSION_RESULT_SSL_FAIL_TO_OPEN       = 0x0503,
  OMADM_SESSION_RESULT_FATAL_NTWK_ERROR       = 0x0504,
  OMADM_SESSION_RESULT_TREE_NODE_EXISTS       = 0x1000,
  OMADM_SESSION_RESULT_TREE_NODE_MISSING      = 0x1001,
  OMADM_SESSION_RESULT_LEAF_NODE_OP_ERROR     = 0x1002,
  OMADM_SESSION_RESULT_INVALID_NODE_TYPE      = 0x1003,
  OMADM_SESSION_RESULT_UNKNOWN_PROPERTY       = 0x1004,
  OMADM_SESSION_RESULT_DELETE_PERM_NODE       = 0x1005,
  OMADM_SESSION_RESULT_ACCESS_TYPE_INVALID    = 0x1006,
  OMADM_SESSION_RESULT_BAD_NAME_FOR_TREE      = 0x1007,
  OMADM_SESSION_RESULT_PARTIAL_WRITE_EXT_DATA = 0x1008,
  OMADM_SESSION_RESULT_EXT_WRITE_TEMP_BLOCKED = 0x1009,
  OMADM_SESSION_RESULT_VALUE_NOT_WRITABLE     = 0x100A,
  OMADM_SESSION_RESULT_VALUE_NOT_READABLE     = 0x100B,
  OMADM_SESSION_RESULT_CANNOT_EXECUTE_NODE    = 0x100C,
  OMADM_SESSION_RESULT_TREE_OPEN_ERROR        = 0x100D,
  OMADM_SESSION_RESULT_TREE_COMMIT_ERROR      = 0x100E,
  OMADM_SESSION_RESULT_BOOTSTRAP_RSVD         = 0x2000,
  OMADM_SESSION_RESULT_FUMO_RSVD              = 0x3000,
}SWI_TYPE_OMADM_SESSION_RESULT;

typedef enum 
{
  OMADM_SESSION_COMMIT_DATA_NOT_UPDATED       = 0x00,  //Update did not occur for any DC/PRL/FUMO session
  OMADM_SESSION_COMMIT_DATA_UPDATED           = 0x01,  //DC/PRL/FUMO update occurred.
}SWI_TYPE_OMADM_SESSION_COMMIT;


typedef struct SWI_STRUCT_OMADM_SESSION_STATE
{
  SWI_U32 sizeStruct;
  SWI_TYPE_OMADM_SESSION_STATE                nState;
  SWI_U16                                         nHFARetryTime;
  SWI_TYPE_OMADM_SESSION_TYPE                 nLastSessionType;
  SWI_TYPE_OMADM_SESSION_INITIATOR            nLastSessionInitiator;
  SWI_TYPE_OMADM_SESSION_UI_MODE              nUIMode;
  SWI_TYPE_OMADM_SESSION_RESULT               nLastSessionResult;
  SWI_TYPE_OMADM_SESSION_COMMIT               nLastSessionCommit;
}SWI_STRUCT_OMADM_SESSION_STATE;

typedef enum 
{
  OMADM_NIA_STATE_PENDING_NONE                = 0x00,
  OMADM_NIA_STATE_PENDING_BLOCKED             = 0x01,
  OMADM_NIA_STATE_PENDING_READY               = 0x02,
}SWI_TYPE_OMADM_NIA_PENDING;

typedef enum 
{
  OMADM_NIA_UI_MODE_UNKNOWN                   = 0x00,
  OMADM_NIA_UI_MODE_BACKGROUND                = 0x01,
  OMADM_NIA_UI_MODE_INFORMATIVE               = 0x02,
  OMADM_NIA_UI_MODE_INTERACTIVE               = 0x03,
  OMADM_NIA_UI_MODE_DORMANT_INTERRUPT         = 0x04,
}SWI_TYPE_OMADM_NIA_UI_MODE;

typedef enum SWI_TYPE_OMADM_NIA_SESSION_TYPE
{
	OMADM_NIA_SESSION_TYPE_UNKNOWN				= 0x00,	// Placeholder
	OMADM_NIA_SESSION_TYPE_DEVICE_CONFIG		= 0x01,	// Device Configuration
	OMADM_NIA_SESSION_TYPE_CDMA_PRL_UPDATE	= 0x02,	// CDMA PRL Update
	OMADM_NIA_SESSION_TYPE_FUMO					= 0x03,	//FUMO
} SWI_TYPE_OMADM_NIA_SESSION_TYPE;

typedef struct SWI_STRUCT_OMADM_NI_ALERT
{
  SWI_U32 sizeStruct;
  SWI_TYPE_OMADM_NIA_PENDING                  nPending;		// 8 bit
  SWI_TYPE_OMADM_NIA_UI_MODE                  nUIMode;		// 8 bit
  SWI_TYPE_OMADM_NIA_UI_MODE                  nForceUIMode;	// 8 bit
  SWI_TYPE_OMADM_NIA_SESSION_TYPE                 nType;		// 8 bit
}SWI_STRUCT_OMADM_NI_ALERT;

typedef enum 
{
  OMADM_NI_ALERT_RESP_STATUS_ACCEPTED         = 0x00,
  OMADM_NI_ALERT_RESP_STATUS_UNEXPECTED       = 0x01,
  OMADM_NI_ALERT_RESP_STATUS_INVALID          = 0x02,
}SWI_TYPE_OMADM_NI_ALERT_RESP_STATUS;

typedef struct SWI_STRUCT_OMADM_NI_ALERT_RESP
{
  SWI_U32                                      sizeStruct;
  SWI_TYPE_OMADM_NI_ALERT_RESP_STATUS         nStatus;
  SWI_U8                                       bQueuedForReattempt;
}SWI_STRUCT_OMADM_NI_ALERT_RESP;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_DISPLAY
{
  SWI_U32                                         sizeStruct;
  SWI_U16                                         nMinDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U16                                         nMaxDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U16                                         nTextLength;		// length of text to display
  SWI_U8*										 psText;     // Variable length text (not NULL terminated)
}SWI_STRUCT_OMADM_UI_ALERT_DISPLAY;

typedef enum 
{
  OMADM_UI_ALERT_CONFIRM_REJECT               = 0x00,
  OMADM_UI_ALERT_CONFIRM_ACCEPT               = 0x01,
  OMADM_UI_ALERT_CONFIRM_UNSPECIFIED          = 0xFF,
}SWI_TYPE_OMADM_UI_ALERT_CONFIRM_DEFAULT;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_CONFIRM
{
  SWI_U32                                         sizeStruct;
  SWI_U16                                         nMinDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U16                                         nMaxDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_TYPE_OMADM_UI_ALERT_CONFIRM_DEFAULT		 nDefResp;
  SWI_U16                                         nTextLength;
  SWI_U8                                          *psText; // Variable length text
}SWI_STRUCT_OMADM_UI_ALERT_CONFIRM;

typedef enum 
{
  OMADM_UI_ALERT_USER_CONFIRM_USER            = 0x00,
  OMADM_UI_ALERT_USER_CONFIRM_CANCEL          = 0x01,
}SWI_TYPE_OMADM_UI_ALERT_USER_CONFIRM;

typedef enum 
{
  OMADM_UI_CONFIRM_RESP_REJECT                = 0x00,
  OMADM_UI_CONFIRM_RESP_CONFIRM               = 0x01,
}SWI_TYPE_OMADM_UI_ALERT_CONFIRM_RESP;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_CONFIRM_RESP
{
  SWI_U32                                      sizeStruct;
  SWI_TYPE_OMADM_UI_ALERT_USER_CONFIRM        nUserAction;
  SWI_TYPE_OMADM_UI_ALERT_CONFIRM_RESP        nResp;     //ignored if nUserAction = OMADM_UI_ALERT_USER_CONFIRM_CANCEL
}SWI_STRUCT_OMADM_UI_ALERT_CONFIRM_RESP;

typedef enum 
{
  OMADM_UI_ALERT_INPUT_TYPE_ALPHANUM          = 0x00, // Alpha-numeric input
  OMADM_UI_ALERT_INPUT_TYPE_NUMERIC           = 0x01, // Numeric
  OMADM_UI_ALERT_INPUT_TYPE_DATE              = 0x02, // "DDMMYYYY"
  OMADM_UI_ALERT_INPUT_TYPE_TIME              = 0x03, // "hhmmss"
  OMADM_UI_ALERT_INPUT_TYPE_PHONENUM          = 0x04, // Phone number input (All numeric characters, "+","p","w" and "s". "+" must be first if present in phone number)
  OMADM_UI_ALERT_INPUT_TYPE_IP                = 0x05, // IP address input www.xxx.yyy.zzz
  OMADM_UI_ALERT_INPUT_TYPE_IPV6              = 0x06, // IPV6 input
}SWI_TYPE_OMADM_UI_ALERT_INPUT_TYPE;

typedef enum 
{
  OMADM_UI_ALERT_ECHO_TYPE_TEXT               = 0x00, //Text input (default)
  OMADM_UI_ALERT_ECHO_TYPE_PASSWORD           = 0x01, //Password input (hide/mask user input text)
}SWI_TYPE_OMADM_UI_ALERT_ECHO_TYPE;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_INPUT
{
  SWI_U32                                         sizeStruct;
  SWI_U16                                         nMinDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U16                                         nMaxDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U16                                         nTextLength;
 // SWI_U8                                          psText[1]; // Variable length text
  SWI_U16                                         nMaxLenUserInput; // 0xFFFF indicates not specified
  SWI_TYPE_OMADM_UI_ALERT_INPUT_TYPE			 nInputType;
  SWI_TYPE_OMADM_UI_ALERT_ECHO_TYPE				 nEcho;
  SWI_U16                                         nPromptLength;
  SWI_U8*                                         psText; // Variable length text (includes Text 1st and prompt 2nd - not NULL terminated)
}SWI_STRUCT_OMADM_UI_ALERT_INPUT;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_INPUT_RESP
{
  SWI_U32                                         sizeStruct;
  SWI_TYPE_OMADM_UI_ALERT_USER_CONFIRM			 nUserAction;
  SWI_U16                                         nTextLength; // nTextLength/strText ignored if nUserAction = OMADM_UI_ALERT_USER_CONFIRM_CANCEL
  SWI_U8*                                         psText; // Variable length text
}SWI_STRUCT_OMADM_UI_ALERT_INPUT_RESP;

typedef enum 
{
  OMADM_UI_ALERT_CHOICE_SINGLE                = 0x00, //User can only select a single choice
  OMADM_UI_ALERT_CHOICE_MULTIPLE              = 0x01, //User allowed multiple selections
}SWI_TYPE_OMADM_UI_ALERT_CHOICE_TYPE;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_CHOICE
{
  SWI_U32                                         sizeStruct;
  SWI_TYPE_OMADM_UI_ALERT_CHOICE_TYPE            nChoiceType;
  SWI_U8                                          nNumChoices;
  SWI_U16                                         nMinDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U16                                         nMaxDisplayTime;  //in seconds -- 0xFFFF indicates not specified
  SWI_U32                                         dwChoiceMask;     //indicates default choices
  SWI_U16                                         nTextLength;
  SWI_U8*                                         psText; // Variable length text (not NULL terminated)
}SWI_STRUCT_OMADM_UI_ALERT_CHOICE;

typedef struct SWI_STRUCT_OMADM_UI_ALERT_CHOICE_RESP
{
  SWI_U32                                         sizeStruct;
  SWI_TYPE_OMADM_UI_ALERT_USER_CONFIRM           nUserAction;
  SWI_U32                                         dwChoiceMask;   //indicates user selected choice(s)
}SWI_STRUCT_OMADM_UI_ALERT_CHOICE_RESP;


typedef struct SWI_STRUCT_OMADM_NODE_VALUE_REQUEST
{
  SWI_U32                                         sizeStruct;
  SWI_U16                                         nNodePathLength;
  SWI_U8*                                         psText;  //variable length text (not NULL terminated)
}SWI_STRUCT_OMADM_NODE_VALUE_REQUEST;


	
typedef enum 
{
	OMADM_NODE_VALUE_RESP_SUCCESS               = 0x00,
	OMADM_NODE_VALUE_RESP_FAIL_UNSPECIFIED      = 0x01,
	OMADM_NODE_VALUE_RESP_DM_NOT_SUPPORTED      = 0x02,
	OMADM_NODE_VALUE_RESP_INVALID_PARAM         = 0x03,
	OMADM_NODE_VALUE_RESP_INVALID_OPTION        = 0x04,
	OMADM_NODE_VALUE_RESP_DEVICE_BUSY           = 0x05,
	OMADM_NODE_VALUE_RESP_DM_SESSION_BUSY       = 0x06,
	OMADM_NODE_VALUE_RESP_UNSUPPORTED_NODE      = 0x07,
	OMADM_NODE_VALUE_RESP_ACCESS_DENIED         = 0x08,
} SWI_TYPE_OMADM_NODE_VALUE_RESP_STATUS;
//}SWI_TYPE_OMADM_STATUS_RESP;

typedef struct SWI_STRUCT_OMADM_NODE_VALUE_RESPONSE
{
  SWI_U32                                         sizeStruct;
  SWI_TYPE_OMADM_STATUS_RESP					 nStatus;
  SWI_U16                                         nNodeFormatLength;
  SWI_U16                                         nNodeTypeLength;
  SWI_U16                                         nNodeValueLength;
  SWI_U8*                                         psText; //include Format, Type, Value strings (in that order - not NULL terminated)
}SWI_STRUCT_OMADM_NODE_VALUE_RESPONSE;

typedef struct SWI_STRUCT_OMADM_NODE_VALUE
{
  SWI_U32                                         sizeStruct;
  SWI_U16                                         nNodePathLength;
  SWI_U16                                         nNodeFormatLength;
  SWI_U16                                         nNodeTypeLength;
  SWI_U16                                         nNodeValueLength;
  SWI_U8*                                         psText; //includes Path,Format,Type,Value strings (in that order - not NULL terminated)
}SWI_STRUCT_OMADM_NODE_VALUE;

// OMA-DM Payloads

typedef struct cns_dm_config_get_resp
{
	SWI_U16                  obj_ver;
  SWI_U8                   device_cap;
  SWI_U8                   account_max;
  SWI_U8                   account_current;
  SWI_U8                   account_change_mask; /* boolean - notification */
  SWI_U32                  session_cap;
  SWI_U32                  session_enabled_state;
  SWI_U8                   hfa_attempted_flag; /* boolean */
  
} cns_dm_config_get_resp;

#ifdef __cplusplus
}
#endif

