/*
 *  swimacrcodes.h
 *  swimac
 *
 *  Created by Russ Winsper on 12/30/06.
 *  Copyright 2006 Sierra Wireless. All rights reserved.
 *
 */

#ifndef __SWIMACRCODES__
#define __SWIMACRCODES__

#ifdef __cplusplus
extern "C"	{
#endif

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_RCODE - Return Codes
//
// Purpose:	All function calls will return one of the return codes noted in the type 
//			definition on the following page. In the event you receive a return
//			code not enumerated in this list, notify Sierra Wireless via e-mail to 
//			sdk@sierrawireless.com and report the function call and the return code
//			received. This should be treated as a fatal error in the system.
//
//			A general interpretation of return codes is provided below. Only return 
//			codes with special handling will be discussed in the function descriptions.
//
// Members:	SWI_RCODE_OK							- request succeeded.
//			The function executed properly and an output data should be accurately 
//			returned. Some functions do have additional status outputs to indicate 
//			the validity of the returned data. It is possible that the function can 
//			execute normally but due to modem or network conditions, the output is 
//			not meaningful. Such cases are noted in the function descriptions.
//
//			SWI_RCODE_NOT_SUP						- not supported.
//			The function is defined for other technologies and is not supported on 
//			this particular product.
//
//			SWI_RCODE_SMALL_BUF						- buffer too small.
//			A buffer length passed for an output string parameter was not large enough 
//			to receive the output. The return data is invalid. A repeat call with a 
//			longer buffer should succeed.
//
//			SWI_RCODE_CLOSED						- not used
//
//			SWI_RCODE_INVALID_PAR					- invalid parameter.
//			The function included a parameter outside of the valid range. This is
//			commonly caused by a null pointer, or a zero timeout setting.
//
//			SWI_RCODE_FAILED						- request failed.
//			The function failed to execute correctly in the modem firmware. Any return
//			data should be ignored. This may be caused by timing or queue issues 
//			within the firmware.
//
//			SWI_RCODE_UNEXPECTED_RESP				- response is unexpected.
//			The function is returning data without detecting a processing fault, but 
//			the data does not match the expected range or format. A retry of the 
//			function may yield better results.
//
//			SWI_RCODE_REQUEST_TIMEOUT				- request timed out.
//			The function could not return within the time allowed by the timeout
//			parameter.
//
//			SWI_RCODE_BUSY							- busy.
//			There is a currently outstanding API function call. This indicates that 
//			more than one process or thread is trying to use the API simultaneously.
//
//			SWI_RCODE_SYSTEM_ERROR					- system function calls failed.
//			A Windows operating system error has occurred. You must call the
//			Windows service GetLastError to have the OS inform you of the specific 
//			error. This is typically due to a memory resource problem or data type
//			conversion error.
//
//			SWI_RCODE_API_NOT_OPEN					- function called when SWI not openned.
//														most of old function returns SWI_RCODE_FAILED instead
//
//			SWI_RCODE_DEVICE_DISABLED				- Require manual operation to turn ON Hardware again.
//	
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following CNS error codes are received, the most likely cause is
//			the use of an incorrect API version
//
//		    SWI_RCODE_CNS_FAILED					- CNS layer failure
//										  
//			SWI_RCODE_CNS_OPERATION_ID_INVALID		- Invalid CNS operation ID 
//
//			SWI_RCODE_CNS_OBJECT_ID_INVALID			- Invalid CNS object ID 
//								
//			SWI_RCODE_CNS_UNEXPECTED_NOTIFICATION	- notification received but not
//													  asked for 
//							
//			SWI_RCODE_CNS_ILLEGAL_NOTIFICATION	    - spurious notification not handled
//													  by CNS 
//												
//			SWI_RCODE_CNS_CALLBACK_FAILURE		    - callback function invalid
//
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following general API operation failure codes are received, the most
//			likely causes are:
//			1) not registering callback immediately after starting the API
//			2) not releasing the notification thread in a timely manner
//
//			SWI_RCODE_FRAME_QUEUE_FULL				- frame queue full 
//
//			SWI_RCODE_FRAME_QUEUE_EMPTY				- frame queue empty 
//
//			SWI_RCODE_PUT_TIMEOUT			        - put into queue failed 
//
//			SWI_RCODE_GET_TIMEOUT			        - get from queue failed 
//
//			SWI_RCODE_BAD_FRAME				        - a defective frame was passed to a
//													  layer
//
//			SWI_RCODE_CANCEL						- a Put or Get queue operation has
//													  been canceled
//
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following CWE error codes are received, the most likely cause is the use
//			of an incorrect API version
//
//			SWI_RCODE_CWE_FAILED					- CWE layer failure 
//
//			SWI_RCODE_CWE_MSG_ID_INVALID		    - CWE invalid MsgID 
//
//			SWI_RCODE_CWE_UNEXPECTED_NOTIFICATION   - notification received but not
//													  asked for 
//
//			SWI_RCODE_CWE_ILLEGAL_NOTIFICATION	    - spurious notification not handled
//													  by CWE 
//
//			SWI_RCODE_CWE_CALLBACK_FAILURE          - callback function invalid
//
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following OID error codes are received, the most likely cause is
//			the use of an incorrect API version or incompatible driver version.
//
//			SWI_RCODE_OID_BUFFER_ID_INVALID			- Oid buffer ID is invalid
//
//			SWI_RCODE_OID_FAILED					- Oid layer failure
//
//			SWI_RCODE_OID_UNEXPECTED_NOTIFICATION	- notification received but not
//													  asked for 
//
//			SWI_RCODE_OID_ILLEGAL_NOTIFICATION		- spurious notification not handled
//													  by CWE 
//
//			SWI_RCODE_OID_CALLBACK_FAILURE			- callback function invalid
//
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following LINK error codes are received, the most likely cause is
//			the use of an incorrect API version or incompatible driver version.
//
//			SWI_RCODE_LINK_FAILED					- link layer failure 
//
//			SWI_RCODE_LINK_MSG_ID_INVALID			- invalid Oid ID
//
//			SWI_RCODE_LINK_NO_PENDING_DATA			- link layer response to indicate
//													  no pending data
//
//			SWI_RCODE_PORT_OPEN_FAIL				- failed to open COMM port
// 
//			SWI_RCODE_PORT_INITIALIZE_FAIL			- failed to initialize COMM port
//
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following DATA error codes are received, the most likely causes are:
//			1) an incorrect API version or incompatible driver version is used
//			2) not registering callback immediately after starting the API
//
//			SWI_RCODE_DATA_INIT_FAILED				- failure to initialize data layer
//
//			SWI_RCODE_DATA_SEND_FAILED		        - data layer send failed
//
/////////////////////////////////////////////////////////////////////////////////
//
//			If the following PROFILE error codes are received, the most likely cause
//			is the use of an incorrect API version or incompatible driver version.
//
//			SWI_RCODE_PROFILE_FAILED				- profile layer failure
//
//			SWI_RCODE_PROFILE_MSG_ID_INVALID	    - profile invalid MsgID
//
//			SWI_RCODE_PROFILE_OP_CODE_INVALID	    - profile invalid Op Code
//
//		    SWI_RCODE_REQUEST_REJECTED				- driver/hardware rejected operation
//													  requested of it
//
//		    SWI_RCODE_CAIT_INIT_FAILED				- failure to initialize CAIT layer
//
// Notes:	Note: You must use the defined enumeration types, not the numeric values. 
//			Sierra Wireless may change the numbering in future editions of the API.
//
/////////////////////////////////////////////////////////////////////////////////
//
//
//  The following error codes are related to internal power control handling and
//  are not applicable to the SDK.
//
//  SWI_RCODE_PWR_CTRL_INT_FAILED 
//	SWI_RCODE_PWR_CTRL_INVALID_CMD_CODE,
//	SWI_RCODE_PWR_CTRL_GET_CTRLPORT_FAILED,
//	SWI_RCODE_PWR_CTRL_GET_DATAPORT_FAILED,
//	SWI_RCODE_PWR_CTRL_SET_PWR_STATE_FAILED,
//	SWI_RCODE_PWR_CTRL_GET_PWR_STATE_FAILED,
//	SWI_RCODE_PWR_CTRL_GET_VSP_PORTS_FAILED,
//	SWI_RCODE_PWR_CTRL_INSTALL_VSP_FAILED,
//	SWI_RCODE_PWR_CTRL_ENABLE_VSP_FAILED,
//	SWI_RCODE_PWR_CTRL_NOT_SUPPORTED
//
/////////////////////////////////////////////////////////////////////////////////
//
//  The following error codes are related to mux support
//
//  SWI_RCODE_MUXINT_LOAD_FAILED,
//	SWI_RCODE_MUXINT_INCORRECT_VER,
//	SWI_RCODE_MUXINT_INTERNAL_FAIL,
//	SWI_RCODE_MUXINT_ACQLOCK_FAIL,
//	SWI_RCODE_MUXINT_MUXMODE_FAIL,
//	SWI_RCODE_MUXINT_DEVICE_NOT_FOUND,
//	SWI_RCODE_MUXINT_INVALID_OPENPARAMS,
//	SWI_RCODE_MUXINT_QUERYTYPE_INVALID,
//	SWI_RCODE_MUXINT_QUERYDLCI_NOTSUP,
//	SWI_RCODE_MUXINT_PORT_ALREADY_ACQUIRED
//
//	SWI_RCODE_MULTI_DEVICE			- This is only supported in the USB driver v. 1.2.1 and on
//
/////////////////////////////////////////////////////////////////////////////////


typedef enum
{
    SWI_RCODE_OK,			// 0
    SWI_RCODE_NOT_SUP,
    //SWI_RCODE_NOT_SUPPORTED = SWI_RCODE_NOT_SUP,
    SWI_RCODE_SMALL_BUF,
    //SWI_RCODE_SMALL_BUFFER = SWI_RCODE_SMALL_BUF,
    SWI_RCODE_CLOSED,
	SWI_RCODE_INVALID_PAR,
    SWI_RCODE_FAILED,		// 5
    SWI_RCODE_UNEXPECTED_RESP,
	SWI_RCODE_REQUEST_TIMEOUT,
    SWI_RCODE_BUSY,
    SWI_RCODE_SYSTEM_ERROR,
	SWI_RCODE_API_NOT_OPEN,    //VB API 10
	SWI_RCODE_DEVICE_DISABLED,
	SWI_RCODE_INVALID_FUNCPTR,

	// CnS return codes
    SWI_RCODE_CNS_FAILED = 100,
	SWI_RCODE_CNS_OPERATION_ID_INVALID,
	SWI_RCODE_CNS_OBJECT_ID_INVALID,
	SWI_RCODE_CNS_UNEXPECTED_NOTIFICATION,
	SWI_RCODE_CNS_ILLEGAL_NOTIFICATION,
	SWI_RCODE_CNS_CALLBACK_FAILURE,

	SWI_RCODE_FRAME_QUEUE_FULL   = 150,
	SWI_RCODE_FRAME_QUEUE_EMPTY,
	SWI_RCODE_PUT_TIMEOUT,
	SWI_RCODE_GET_TIMEOUT,
	SWI_RCODE_BAD_FRAME,
	SWI_RCODE_CANCEL,

	// CWE return codes
    SWI_RCODE_CWE_FAILED = 200,
	SWI_RCODE_CWE_MSG_ID_INVALID,
	SWI_RCODE_CWE_UNEXPECTED_NOTIFICATION,
	SWI_RCODE_CWE_ILLEGAL_NOTIFICATION,
	SWI_RCODE_CWE_CALLBACK_FAILURE,

	// OID return codes
	SWI_RCODE_OID_BUFFER_ID_INVALID,
    SWI_RCODE_OID_FAILED,
	SWI_RCODE_OID_UNEXPECTED_NOTIFICATION,
	SWI_RCODE_OID_ILLEGAL_NOTIFICATION,
	SWI_RCODE_OID_CALLBACK_FAILURE,

	// Link layer return codes
	SWI_RCODE_LINK_FAILED = 350,
	SWI_RCODE_LINK_MSG_ID_INVALID,
	SWI_RCODE_LINK_NO_PENDING_DATA,
	SWI_RCODE_PORT_OPEN_FAIL,
	SWI_RCODE_PORT_INITIALIZE_FAIL,

	SWI_RCODE_DATA_INIT_FAILED = 400,
	SWI_RCODE_DATA_SEND_FAILED,

	SWI_RCODE_PROFILE_FAILED = 500,
	SWI_RCODE_PROFILE_MSG_ID_INVALID,
	SWI_RCODE_PROFILE_OP_CODE_INVALID,

    SWI_RCODE_REQUEST_REJECTED = 600,

	// CAIT return codes
    SWI_RCODE_CAIT_INIT_FAILED = 700,

	//PowerControl return Codes
	SWI_RCODE_PWR_CTRL_INT_FAILED = 800,
	SWI_RCODE_PWR_CTRL_INVALID_CMD_CODE,
	SWI_RCODE_PWR_CTRL_GET_CTRLPORT_FAILED,
	SWI_RCODE_PWR_CTRL_GET_DATAPORT_FAILED,
	SWI_RCODE_PWR_CTRL_SET_PWR_STATE_FAILED,
	SWI_RCODE_PWR_CTRL_GET_PWR_STATE_FAILED,
	SWI_RCODE_PWR_CTRL_GET_VSP_PORTS_FAILED,
	SWI_RCODE_PWR_CTRL_INSTALL_VSP_FAILED,
	SWI_RCODE_PWR_CTRL_ENABLE_VSP_FAILED,
	SWI_RCODE_PWR_CTRL_NOT_SUPPORTED,

	// Notification
	SWI_RCODE_NOTIFY_FIRST_CALLBACK,
	SWI_RCODE_NOTIFY_LAST_CALLBACK,

	//DrvInterface return codes. SW MUX Drivers only
	SWI_RCODE_MUXINT_LOAD_FAILED = 900,
	SWI_RCODE_MUXINT_INCORRECT_VER,
	SWI_RCODE_MUXINT_INTERNAL_FAIL,
	SWI_RCODE_MUXINT_ACQLOCK_FAIL,
	SWI_RCODE_MUXINT_MUXMODE_FAIL,
	SWI_RCODE_MUXINT_DEVICE_NOT_FOUND,
	SWI_RCODE_MUXINT_INVALID_OPENPARAMS,
	SWI_RCODE_MUXINT_QUERYTYPE_INVALID,
	SWI_RCODE_MUXINT_QUERYDLCI_NOTSUP,
	SWI_RCODE_MUXINT_PORT_ALREADY_ACQUIRED,
	SWI_RCODE_MULTI_DEVICE,
	SWI_RCODE_MUXINT_NDIS_NOTSUPPORTED,
	SWI_RCODE_MUXINT_CALL_INPROGRESS,
	SWI_RCODE_MUXINT_NIC_DEVICE_DISABLED,
	
	//LBS PA response code - PAErrType
	SWI_RCODE_LBS_PA_NO_ERROR = 1000,
	SWI_RCODE_LBS_PA_INTERNAL_ERROR,
	SWI_RCODE_LBS_PA_INVALID_CLIENT_ID,
	SWI_RCODE_LBS_PA_ERROR_IN_PARAM_TO_SET,
	SWI_RCODE_LBS_PA_ERROR_IN_LOCK_TYPE,
	SWI_RCODE_LBS_PA_PHONE_OFFLINE,
	SWI_RCODE_LBS_PA_SET_COMMAND_ALREADY_ACTIVE,
	SWI_RCODE_LBS_PA_INCORRECT_APP_INFO,

	//LBS PD response code - PDErrType
	SWI_RCODE_LBS_PD_NO_ERROR = 1050,
	SWI_RCODE_LBS_PD_INTERNAL_MODEM_ERROR,
	SWI_RCODE_LBS_PD_BAD_SERVICE_TYPE,
	SWI_RCODE_LBS_PD_BAD_SESSION_TYPE,
	SWI_RCODE_LBS_PD_INVALID_PRIVACY,
	SWI_RCODE_LBS_PD_INVALID_DATA_DOWNLOAD,
	SWI_RCODE_LBS_PD_INVALID_NETWORK_ACCESS,
	SWI_RCODE_LBS_PD_INVALID_OPERATION_MODE,
	SWI_RCODE_LBS_PD_INVALID_NUMBER_OF_FIXES,
	SWI_RCODE_LBS_PD_INVALID_SERVER_INFO,
	SWI_RCODE_LBS_PD_INVALID_TIMEOUT,
	SWI_RCODE_LBS_PD_INVALID_QOS_PARAMETER,
	SWI_RCODE_LBS_PD_NO_SESSION_ACTIVE,
	SWI_RCODE_LBS_PD_SESSION_ALREADY_ACTIVE,
	SWI_RCODE_LBS_PD_SESSION_BUSY,
	SWI_RCODE_LBS_PD_PHONE_OFFLINE,
	SWI_RCODE_LBS_PD_CDMA_LOCK_ERROR,
	SWI_RCODE_LBS_PD_GPS_LOCK_ERROR,
	SWI_RCODE_LBS_PD_INVALID_STATE,
	SWI_RCODE_LBS_PD_CONNECTION_FAILURE,
	SWI_RCODE_LBS_PD_NO_BUFFERS_AVAILABLE,
	SWI_RCODE_LBS_PD_SEARCHER_ERROR,
	SWI_RCODE_LBS_PD_CANNOT_REPORT_NOW,
	SWI_RCODE_LBS_PD_MODE_NOT_SUPPORTED,
	SWI_RCODE_LBS_PD_OTHER_ERROR,
	SWI_RCODE_LBS_PD_FIX_RATE_TOO_LARGE,

	//CDMA
} SWI_RCODE;

#ifdef __cplusplus
}
#endif

#endif // __SWIMACRCODES__
