/*
 *  swimacstoragemedia.h
 *  swimac
 *
 *  Created by Mark de Jong on 11/3/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"

/////////////// REMOVABLE MEDIA //////////////////////////
typedef enum SWI_TYPE_REMOVABLE_MEDIA
{
	REMOVABLE_MEDIA_MINI_SD   = 0x0001,
	REMOVABLE_MEDIA_MICRO_SD  = 0x0002,
} SWI_TYPE_REMOVABLE_MEDIA;

typedef enum SWI_TYPE_REMOVABLE_MEDIA_SET_STATUS_RESP
{
	REMOVABLE_MEDIA_STATUS_RESP_SUCCESS						= 0x00, // Action Succeeded
	REMOVABLE_MEDIA_STATUS_RESP_MEDIA_UNSUPPORTED			= 0x01, // Action failed (media not supported) 
	REMOVABLE_MEDIA_STATUS_RESP_SECURITY_ACCESS_DENIED    	= 0x02, // Action failed (security access denied)
	REMOVABLE_MEDIA_STATUS_RESP_INVALID_PARAMETER			= 0x03, // Action failed (invalid parameter)
} SWI_TYPE_REMOVABLE_MEDIA_SET_STATUS_RESP;

typedef struct SWI_STRUCT_RM_CONFIG
{
	SWI_U32 sizeStruct;
	SWI_U16 nFeatureSupportMask;  //contains RM capability support. See SWI_TYPE_REMOVABLE_MEDIA for bit definitions
	SWI_U16 nFeatureEnableMask;   //contains RM enable status.  See SWI_TYPE_REMOVABLE_MEDIA for bit definitions
} SWI_STRUCT_RM_CONFIG;

typedef struct SWI_STRUCT_RM_CONFIG_SET
{
	SWI_U32 sizeStruct;
	SWI_U16 nRMFeature;       // SWI_TYPE_REMOVABLE_MEDIA: Note-- can only disable/enable 1 media at a time
	SWI_U8  bEnable;
} SWI_STRUCT_RM_CONFIG_SET;


/////////////// SWOC/TRU-INSTALL //////////////////////////
typedef enum SWI_TYPE_SWOC_FEATURE
{
  SWOC_GENERAL_FEATURE		= 0x0001,
  SWOC_ACCESS_MODEM_MODE	= 0x0002,
} SWI_TYPE_SWOC_FEATURE;

typedef enum SWI_TYPE_SWOC_SET_STATUS_RESP
{
  SWOC_STATUS_RESP_SUCCESS						= 0x00, // Action Succeeded
  SWOC_STATUS_RESP_INVALID_PARAMETER			= 0x01, // Action failed (invalid parameter)
  SWOC_STATUS_RESP_UNSUPPORTED					= 0x02, // Action failed (feature not supported) 
  SWOC_STATUS_RESP_ENABLE_UNSUPPORTED			= 0x03, // Action failed (enable/disable not allowed)
  SWOC_STATUS_RESP_REQ_GEN_SWOC					= 0x04, // Action failed (requires general SWoC)
  SWOC_STATUS_RESP_SECURITY_ACCESS_DENIED    	= 0x05, // Action failed (security access denied)
} SWI_TYPE_SWOC_SET_STATUS_RESP;


typedef struct SWI_STRUCT_SWOC_CONFIG
{
  SWI_U32 sizeStruct;
  SWI_U16 nFeatureSupportMask;				//contains SWOC feature support. See SWI_TYPE_SWOC_FEATURE for bit definitions
  SWI_U16 nFeatureEnableStateMask;			//contains SWOC enable/disable state.  See SWI_TYPE_SWOC_FEATURE for bit definitions
  SWI_U16 nFeatureEnableHostCapabilityMask; //contains SWOC enable/disable host capability.  See SWI_TYPE_SWOC_FEATURE for bit definitions
  SWI_U16 nFeatureOEMUnlockReqMask;			//contains SWOC host change requires OEM unlock.  See SWI_TYPE_SWOC_FEATURE for bit definitions
} SWI_STRUCT_SWOC_CONFIG;

typedef struct SWI_STRUCT_SWOC_CONFIG_SET
{
  SWI_U32 sizeStruct;
  SWI_U16 nSWOCFeature;       // SWI_TYPE_SWOC_FEATURE: Note-- can only disable/enable either general SWOC or SWOC access in modem mode at a time
  SWI_U8  bEnable;      
} SWI_STRUCT_SWOC_CONFIG_SET;



// FUNCTIONS

//
// TODO: Add detail description
SWI_RCODE SwiGetRemovableMediaSupport(SWI_STRUCT_RM_CONFIG *rmConfig, SWI_U32 timeout);

//
// TODO: Add detail description
// Response in pStatus from a SET request
//	• 0x00 – Action succeeded
//	• 0x01 – Action failed (media not supported)
//	• 0x02 – Action failed (security access denied)
//	• 0x03 – Action failed (invalid parameter)
SWI_RCODE SwiSetRemovableMediaSupport(const SWI_STRUCT_RM_CONFIG_SET *rmSetConfig, SWI_U8 *pStatus, SWI_U32 timeout);

SWI_RCODE SwiGetSWoCSupport( SWI_STRUCT_SWOC_CONFIG *swocConfig, SWI_U32 timeout);

SWI_RCODE SwiSetSWoCSupport( const SWI_STRUCT_SWOC_CONFIG_SET *swocSetConfig, SWI_U8 *pStatus, SWI_U32 timeout );

#ifdef __cplusplus
}
#endif