/*
 *  swiprofile.h
 *  swimac
 *
 *  Created by Mark de Jong on 9/10/09.
 *  Copyright 2009 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWI_PROFILE_H__
#define __SWI_PROFILE_H__

#ifdef __cplusplus
extern "C"	{
#endif
	
#include "swimacapi.h"

#define LENGTH_IPAddress		    16
#define LENGTH_AccessPointName		101
#define LENGTH_UserName		        33
#define LENGTH_Label				31
#define LENGTH_Password				33
#define LENGTH_MCCMNC_BUFFER		3
#define MAX_3G_GSM_PROFILES			16

typedef struct __attribute__ ((__packed__)) _CNS_PROFILE_SUMMARY_PAYLOAD
{
	SWI_U8	MaxNumProfiles;				// maximum number of profile the card supports
	SWI_U8	MaxTft;									// maximum number of TFTs per profile
	SWI_U8	DefaultProfile;							// 0 if no profiles defined
	SWI_U8	StatusProfile[MAX_3G_GSM_PROFILES];		// 0x00-Inactive, 0x01-Active, 0x02-Undefined
} CNS_PROFILE_SUMMARY_PAYLOAD;

typedef struct __attribute__ ((__packed__))  _CNS_PROFILE_READ_REQUEST_PAYLOAD
{
	SWI_U8	ProfileId;			// 1-16
	SWI_U8	Type;				// 0x00-basic, 0x01-QoS, 0x02-DNS, 0x03-TFT
	SWI_U8	TFT;				// 1-8, Only valid when TFT type is selected.  Set to 0 otherwise.SWI_U8
} CNS_PROFILE_READ_REQUEST_PAYLOAD;

typedef struct __attribute__ ((__packed__))  _CNS_PROFILE_BASIC_PAYLOAD
{
	SWI_U8	ProfileId;					// 1-16
	SWI_U8	Type;						// 0x00-basic
	SWI_U8	Valid;						// 0x00-invalid, 0x01-valid
	SWI_U8	Pdp;						// 0x00-IPV4, 0x01-PPP, 0x02-IPV6
	SWI_U8	HeaderCompression;			// 0x00-no compression, 0x01-compression on
	SWI_U8	DataCompression;			// 0x00-no compression, 0x01-compression on
	SWI_U8	PdpLength;					// 0-16, 0 indicates dynamic addressing.  Not used by modem, provided only for host storage
	SWI_U8	PdpAddress[LENGTH_IPAddress];	
	SWI_U8	ApnLength;					// 0-100, 0 indicates no APN specified
	SWI_U8	Apn[LENGTH_AccessPointName-1];
	SWI_U8	PdpInitiatedType;			// 0x00-primary, 0x01-secondary, 0x02-network, 0xFF-no context defined
	SWI_U8	PrimaryProfileId;			// 1-16.  This field is only valid if the PDP Initiated Type is Secondary Mobile Initiated
	SWI_U8	AuthenticationType;			// 0x00-none, 0x01-PAP, 0x02-CHAP
	SWI_U8	Username[LENGTH_UserName];	// 32 character NULL terminated string
	SWI_U8	Password[LENGTH_Password];	// 32 character NULL terminated string
	SWI_U8	Label[LENGTH_Label];		// 30 character NULL terminated string
	SWI_U8	AutoActivate;				// 0x00-off, 0x01-always connected, 0x02-connect when there is IP traffic
	SWI_U8	ReadOnly;					// 0x00-read and write enabled, 0x01-read only
	SWI_U8	PromptForPassword;			// 0x00-do not prompt, 0x01-prompt
	SWI_U8	AutoLaunchApp;				// 0x00-don't launch, 0x01-auto launch
	SWI_U16	PdpLingerTimer;				// 0-disable timer, (1-32767) time in minutes
	SWI_U8	SoftwareOptions;			// bitset used by software
	SWI_U8	MCCMNC[LENGTH_MCCMNC_BUFFER];		// Mobile contry code and mobile network code
	SWI_U8	Reserved[11];				// reserved for future use
} CNS_PROFILE_BASIC_PAYLOAD;
	
	SWI_RCODE SwiGetBasicProfile( CNS_PROFILE_BASIC_PAYLOAD *pBasicProfile, SWI_U8 profileID, SWI_U32 timeout );
	SWI_RCODE SwiGetProfileSummary( CNS_PROFILE_SUMMARY_PAYLOAD *pProfileSummary, SWI_U32 timeout  );

#ifdef __cplusplus
}
#endif

#endif /* __SWI_PROFILE_H__ */